var group__new__in__4__11 =
[
    [ "EventConsumeState", "struct_v_s_t_g_u_i_1_1_event_consume_state.html", [
      [ "operator bool", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a9b3baad8c612d81b96e46f84d7e97580", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a60e1fbb077f7c9628bf534ac1f5ce3ed", null ],
      [ "reset", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#ad20897c5c8bd47f5d4005989bead0e55", null ],
      [ "data", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a1e43bf7d608e87228b625cca2c04d641", null ],
      [ "Handled", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a000be40772e717cbf61931b274839832", null ],
      [ "Last", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a5bb588d57db57788977be6802c689996", null ],
      [ "NotHandled", "struct_v_s_t_g_u_i_1_1_event_consume_state.html#a8f13b276344ed5f0d86069166ab1a5e4", null ]
    ] ],
    [ "Event", "struct_v_s_t_g_u_i_1_1_event.html", [
      [ "Event", "struct_v_s_t_g_u_i_1_1_event.html#aee8d9a66825a2b6f00d5af57329a4744", null ],
      [ "Event", "struct_v_s_t_g_u_i_1_1_event.html#a476b6a7884ab5d0250c283d63ca45a1a", null ],
      [ "Event", "struct_v_s_t_g_u_i_1_1_event.html#a83bcf6124a582959b59daa1e053203eb", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_event.html#a091cc4d9fb31558682f8b5323e5a3b9f", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_event.html#a99acf4f42994cb58c4c5465d1cc61b9a", null ],
      [ "consumed", "struct_v_s_t_g_u_i_1_1_event.html#a49945232f356256b15fda93dbe785525", null ],
      [ "id", "struct_v_s_t_g_u_i_1_1_event.html#a7e290573ef1be67b92a2c745e3b00d1d", null ],
      [ "timestamp", "struct_v_s_t_g_u_i_1_1_event.html#a465bef81f6478756e5443025b1f2ddfa", null ],
      [ "type", "struct_v_s_t_g_u_i_1_1_event.html#a2f18e60350b641236ab0e724d0622d1d", null ]
    ] ],
    [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html", [
      [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57", null ],
      [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d", null ],
      [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f", null ],
      [ "add", "struct_v_s_t_g_u_i_1_1_modifiers.html#a70dd2eb8191dd96ba40c4ae6553fc7ff", null ],
      [ "clear", "struct_v_s_t_g_u_i_1_1_modifiers.html#ac8bb3912a3ce86b15842e79d0b421204", null ],
      [ "empty", "struct_v_s_t_g_u_i_1_1_modifiers.html#ac6e61de369e994009e36f344f99c15ad", null ],
      [ "has", "struct_v_s_t_g_u_i_1_1_modifiers.html#a731cb2ca5178db54646a48abf29d5939", null ],
      [ "is", "struct_v_s_t_g_u_i_1_1_modifiers.html#a45c259f4d38ac870d15e99b2ca9c0b4e", null ],
      [ "is", "struct_v_s_t_g_u_i_1_1_modifiers.html#ae927f8a2330174198266cc7b5a2163e5", null ],
      [ "operator!=", "struct_v_s_t_g_u_i_1_1_modifiers.html#aef22a9279e0b6624b7d51b1f24e80a33", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_modifiers.html#a0be60afc7397240655e2fd8fb67b3c11", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_modifiers.html#a1e3ddde3129831fe0d7c57d8e61bc7ec", null ],
      [ "operator==", "struct_v_s_t_g_u_i_1_1_modifiers.html#a0b487af87f2c96caa83076471885f5f1", null ],
      [ "operator==", "struct_v_s_t_g_u_i_1_1_modifiers.html#ae7c0c5c65f6dedaeaa8396223bab1ee0", null ],
      [ "operator|", "struct_v_s_t_g_u_i_1_1_modifiers.html#aaef4e4976fd8a3ab632710b471a024e9", null ],
      [ "remove", "struct_v_s_t_g_u_i_1_1_modifiers.html#ac1fb5ea4d3d74393e28217db05ebb469", null ]
    ] ],
    [ "ModifierEvent", "struct_v_s_t_g_u_i_1_1_modifier_event.html", [
      [ "modifiers", "struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed", null ]
    ] ],
    [ "MousePositionEvent", "struct_v_s_t_g_u_i_1_1_mouse_position_event.html", [
      [ "mousePosition", "struct_v_s_t_g_u_i_1_1_mouse_position_event.html#a1800e41dfb73f77df9be88fdb54f84ce", null ]
    ] ],
    [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html", [
      [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#afa84170837cc62e5a6ad00bf9a87fc56", null ],
      [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#ab76967be0ff9df7f2144bca5e0f81b43", null ],
      [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a4b3370a6d31787f89349ab05b8cf98b1", null ],
      [ "add", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#adea034dec619706b4a8f989a1d357197", null ],
      [ "clear", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#ac8bb3912a3ce86b15842e79d0b421204", null ],
      [ "empty", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#ac6e61de369e994009e36f344f99c15ad", null ],
      [ "has", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a9f6931df5caaa3817f6fb28648319d4f", null ],
      [ "is", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a6863a6d2eb5533f3778073513c798544", null ],
      [ "isLeft", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#ab276099919561d1b0d49c3cd0e44bd76", null ],
      [ "isMiddle", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a079ab622a213cecfca6543d13f09b311", null ],
      [ "isOther", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a5d31638004a221dcfe8946a844a5e39d", null ],
      [ "isRight", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a85f93b21dd887470891f83791c680537", null ],
      [ "operator!=", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a3b537941222a7b70b8bbca23a92151fc", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a837782911f308d49728dc971a95cac88", null ],
      [ "operator==", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a7f5a42f69199a71c7429a77400057152", null ],
      [ "set", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html#a2d75fdf094bfcd1596a7787aa08b55ae", null ]
    ] ],
    [ "MouseEvent", "struct_v_s_t_g_u_i_1_1_mouse_event.html", [
      [ "buttonState", "struct_v_s_t_g_u_i_1_1_mouse_event.html#ae11c9657cc5debc286f7aa78664bd611", null ]
    ] ],
    [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html", [
      [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html#a5b03a459edd4be474d05d18304825312", null ],
      [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html#afd70aa81ccf2d74242dcee442578adc1", null ],
      [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html#aa3f7ebcb10c5813abf6e6040b4705404", null ]
    ] ],
    [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html", [
      [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html#a4480ad27acc63d5a1898827b548689fb", null ],
      [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html#a22a481b6e8eeeba05660913bbc495bb9", null ],
      [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html#aa3daf8edcd959283719bce2ef6ff5bd5", null ]
    ] ],
    [ "MouseDownUpMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html", [
      [ "MouseDownUpMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#af84e4656f43f48b014bd49cf7b8dace3", null ],
      [ "MouseDownUpMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#a62c97a7473e488166fcf4c378201bf4b", null ],
      [ "ignoreFollowUpMoveAndUpEvents", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#abcb2e367e52e88ae929001e9bf73ccc9", null ],
      [ "ignoreFollowUpMoveAndUpEvents", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#ad44a253cf41dfc44f3b587cf7645c6bc", null ],
      [ "clickCount", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#a5b0c02af9a8ef8c0f0333de74bb1ab71", null ],
      [ "IgnoreFollowUpEvents", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#a59c087fa57bfa65bbd27e429d5e9cbb1", null ],
      [ "IgnoreFollowUpEventsMask", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html#a3f7e4fbb326ab93ded3006afb19dae9c", null ]
    ] ],
    [ "MouseDownEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_event.html", [
      [ "MouseDownEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_event.html#a69e7dec0e79732fccbf124d3e9a2f3b3", null ],
      [ "MouseDownEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_event.html#a80b302700c6e7726d9449986ced31966", null ]
    ] ],
    [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html", [
      [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html#a6996b1c242ad6835a95aaed856897120", null ],
      [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html#a51bad606644b76eb8f914432b1475431", null ]
    ] ],
    [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html", [
      [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html#abbd1448384d0d0eb29e19a461f234edc", null ],
      [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html#a2c2ab3849ae58c82d00bb7156ccd1b2b", null ],
      [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html#a28238b33a0fbf5a2e213c8da30b66143", null ]
    ] ],
    [ "MouseCancelEvent", "struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html", [
      [ "MouseCancelEvent", "struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html#a972937b504a1b35085f6e5204f18e638", null ]
    ] ],
    [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html", [
      [ "Flags", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253", [
        [ "DirectionInvertedFromDevice", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253ad790fb0bdc5f0bf20a1eae81e5e7b966", null ],
        [ "PreciseDeltas", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#af028c074e1f093469d6718205957c253a8e3716efd0d53882d8ed84eab83e0c68", null ]
      ] ],
      [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a1c0d2e8544fc3d194f796bb9e73a7b88", null ],
      [ "deltaX", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a217cf0e1abdc7b50ac80346555aea42f", null ],
      [ "deltaY", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a277407d1abe57357b468d032e12d1187", null ],
      [ "flags", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a773b39d480759f67926cb18ae2219281", null ]
    ] ],
    [ "GestureEvent", "struct_v_s_t_g_u_i_1_1_gesture_event.html", [
      [ "Phase", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a0e753040b478a5e7378ed9462dc3817c", [
        [ "Unknown", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a0e753040b478a5e7378ed9462dc3817ca88183b946cc5f0e8c96b2e66e1c74a7e", null ],
        [ "Begin", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a0e753040b478a5e7378ed9462dc3817ca1a06729125544cab7cee73195fc044f0", null ],
        [ "Changed", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a0e753040b478a5e7378ed9462dc3817ca820dbd2b8f606aff866c0bbfb6b737c1", null ],
        [ "End", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a0e753040b478a5e7378ed9462dc3817ca87557f11575c0ad78e4e28abedc13b6e", null ]
      ] ],
      [ "phase", "struct_v_s_t_g_u_i_1_1_gesture_event.html#a3aaaebd424640a55658f6da992e087bd", null ]
    ] ],
    [ "ZoomGestureEvent", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html", [
      [ "ZoomGestureEvent", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html#a44cc5ade7d2f3493762b82cbf7c230a1", null ],
      [ "zoom", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html#a9c59ed4a7b6bdc2b1207e39fabf379a4", null ]
    ] ],
    [ "KeyboardEvent", "struct_v_s_t_g_u_i_1_1_keyboard_event.html", [
      [ "KeyboardEvent", "struct_v_s_t_g_u_i_1_1_keyboard_event.html#a0dccc168c116f81c2fc2079f343361a9", null ],
      [ "character", "struct_v_s_t_g_u_i_1_1_keyboard_event.html#a37312625fe3bfb9f5cbc48c937cd9fc7", null ],
      [ "isRepeat", "struct_v_s_t_g_u_i_1_1_keyboard_event.html#aef096c3bbf6e750546c1c2a1da7992e5", null ],
      [ "virt", "struct_v_s_t_g_u_i_1_1_keyboard_event.html#af6597fffaeac6367c562ddf853cd8241", null ]
    ] ],
    [ "IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html", [
      [ "~IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html#a25b6fd8d8af1061430e7516c4294df45", null ],
      [ "viewOnEvent", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html#aa503cf489fda280eecc550acf87d8174", null ]
    ] ],
    [ "EventType", "group__new__in__4__11.html#ga95d9abac82e22b37b43c182b8af6704f", [
      [ "Unknown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "MouseDown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fabf90db242043990aa80fde01f233665d", null ],
      [ "MouseMove", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fafd060c0c157323f1e43e0704d4f3ffc8", null ],
      [ "MouseUp", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa5c55840fe2a83a886590c780f0aa7031", null ],
      [ "MouseCancel", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704facc00c90abd23024acb572073009c2883", null ],
      [ "MouseEnter", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa68c02431dd2d34247118300cf24c77ea", null ],
      [ "MouseExit", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa0dc1a232157a515e987731d07267723e", null ],
      [ "MouseWheel", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa6924f81750ac471df87fed683bcea516", null ],
      [ "ZoomGesture", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa108a2de26b5b24d5e9d7c279599bab40", null ],
      [ "KeyUp", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa0f8baa14654b1f6ef00fed708c7f198a", null ],
      [ "KeyDown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704facfd07bf1effd88bca04a12a087777354", null ]
    ] ],
    [ "ModifierKey", "group__new__in__4__11.html#ga51910458d0a923b29f1694654d8eb00a", [
      [ "Shift", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa825a3d98017bab11815ad2817201324c", null ],
      [ "Alt", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aaa2e92861b757ab878312dd57993d60cf", null ],
      [ "Control", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aaa1595abbb4c3a326636dd178757cd6c1", null ],
      [ "Super", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa0ce3266d4eb71ad50f7a90aee6d21dcd", null ],
      [ "None", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa6adf97f83acf6453d4a6a4b1070f3754", null ]
    ] ],
    [ "MouseButton", "group__new__in__4__11.html#gab8d93bdfbb0fd7ae143bbfda46bf38bc", [
      [ "None", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca6adf97f83acf6453d4a6a4b1070f3754", null ],
      [ "Left", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca945d5e233cf7d6240f6b783b36a374ff", null ],
      [ "Middle", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bcab1ca34f82e83c52b010f86955f264e05", null ],
      [ "Right", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca92b09c7c48c520c3c55e497875da437c", null ],
      [ "Fourth", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca6e599f7a2a9186d391be4537f105be98", null ],
      [ "Fifth", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca0abdfd715970bd0ef7d5574daa0e6d0b", null ]
    ] ],
    [ "VirtualKey", "group__new__in__4__11.html#ga85a6e0e5dacc5cf40c660ea540b6e9d6", [
      [ "None", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6adf97f83acf6453d4a6a4b1070f3754", null ],
      [ "Back", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0557fa923dcee4d0f86b1409f5c2167f", null ],
      [ "Tab", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a5c6ba25104401c9ee0650230fc6ba413", null ],
      [ "Clear", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6adc30bc0c7914db5918da4263fce93ad2", null ],
      [ "Return", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a988fd738de9c6d177440c5dcf69e73ce", null ],
      [ "Pause", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a105b296a83f9c105355403f3332af50f", null ],
      [ "Escape", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a013ec032d3460d4be4431c6ab1f8f224", null ],
      [ "Space", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ad511f8439ecde36647437fbba67a4394", null ],
      [ "Next", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a10ac3d04253ef7e1ddc73e6091c0cd55", null ],
      [ "End", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "Home", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a8cf04a9734132302f96da8e113e80ce5", null ],
      [ "Left", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a945d5e233cf7d6240f6b783b36a374ff", null ],
      [ "Up", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a258f49887ef8d14ac268c92b02503aaa", null ],
      [ "Right", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a92b09c7c48c520c3c55e497875da437c", null ],
      [ "Down", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a08a38277b0309070706f6652eeae9a53", null ],
      [ "PageUp", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a9b869c510c75c5827ac82e49d4340927", null ],
      [ "PageDown", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aee3677bcca83ece9384b01e43952bf33", null ],
      [ "Select", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae0626222614bdee31951d84c64e5e9ff", null ],
      [ "Print", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a13dba24862cf9128167a59100e154c8d", null ],
      [ "Enter", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6af1851d5600eae616ee802a31ac74701b", null ],
      [ "Snapshot", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ad4e2713d1b1725a1592f9268589f990d", null ],
      [ "Insert", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aa458be0f08b7e4ff3c0f633c100176c0", null ],
      [ "Delete", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6af2a6c498fb90ee345d997f888fce3b18", null ],
      [ "Help", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6a26f548831e6a8c26bfbbd9f6ec61e0", null ],
      [ "NumPad0", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6d3fe859ef4f9d1e8c2e75431c1b7146", null ],
      [ "NumPad1", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a2e6361ee3b8e634cb3b172838a86a351", null ],
      [ "NumPad2", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a63724eb8f83875a8d21dd82b1554a790", null ],
      [ "NumPad3", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aedbd16f7133f080a0c4e479dd55af10c", null ],
      [ "NumPad4", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a672c56a1e1c76b75f47f303823edbfe2", null ],
      [ "NumPad5", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a02a8a1ed101d8903b4b4ab108457716c", null ],
      [ "NumPad6", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a752338562556e765e3db045e17af884b", null ],
      [ "NumPad7", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a2c0344963ddd21bd2951b00664636094", null ],
      [ "NumPad8", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae409cf9af5cfc28aed6cf45ac0edf435", null ],
      [ "NumPad9", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6abec4386b816c0db1696a9906734d2df6", null ],
      [ "Multiply", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae257376d913f3b53cbb4a9b19d770648", null ],
      [ "Add", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aec211f7c20af43e742bf2570c3cb84f9", null ],
      [ "Separator", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a04b2e4188d4ef8051e4699da8af01335", null ],
      [ "Subtract", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a1d9baf077ee87921f57a8fe42d510b65", null ],
      [ "Decimal", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a937504f318f04eaf0f1d701df4c4d7f3", null ],
      [ "Divide", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0b914e196182d02615487e9793ecff3d", null ],
      [ "F1", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae1dffc8709f31a4987c8a88334107e89", null ],
      [ "F2", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6afe5c3684dce76cdd9f7f42430868aa74", null ],
      [ "F3", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a4b6bf4b531770872d4328ce69bef5627", null ],
      [ "F4", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae7e0e72401a9f2718ed0f39f2861d702", null ],
      [ "F5", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a37f438df6a6d5ba4c17ef8ca58562f00", null ],
      [ "F6", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a1faf42f2823f184eb2c9f0dffe5d73f2", null ],
      [ "F7", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a47489eb597b7db34caa24b1fc78fc839", null ],
      [ "F8", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a4787509ad9f9d747a81a30e9dde3d4a7", null ],
      [ "F9", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a892a245e287c163080b23db737d3c4c9", null ],
      [ "F10", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ab213ce22ca6ad4eda8db82966b9b6e5a", null ],
      [ "F11", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a643b0662422d1d0dffa3fca2e2bf28a8", null ],
      [ "F12", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae902674982fc99aa343cdd94da7476c3", null ],
      [ "NumLock", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6acf6cc0261135c6d163fd4305375773d2", null ],
      [ "Scroll", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a105078d294d30c978ca2badf7f376934", null ],
      [ "ShiftModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a5592f6f44f582301112b08ae0d9ae40f", null ],
      [ "ControlModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ac9a56b66fc6e5d13261b02ad173b9664", null ],
      [ "AltModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6a29caa75381017a69d54f7467dfa3fd", null ],
      [ "Equals", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0ccb67e7eaae09d9e4078d161eeca100", null ]
    ] ],
    [ "asKeyboardEvent", "group__new__in__4__11.html#ga549f36e59961f0d3bf85bfcf0286dcdd", null ],
    [ "asModifierEvent", "group__new__in__4__11.html#ga8671db35abe7a32ed6bc90a7c11252b5", null ],
    [ "asMouseDownEvent", "group__new__in__4__11.html#ga489e336b75cdbf6c82e12ffa73de920d", null ],
    [ "asMouseEvent", "group__new__in__4__11.html#gaadbe4e2918050fae1c49639a45cc29d3", null ],
    [ "asMousePositionEvent", "group__new__in__4__11.html#gad31d52d12089ade44329dccbaa86bc20", null ],
    [ "buttonStateFromEventModifiers", "group__new__in__4__11.html#gacc93a453b03a037ebec4987bc8f30a90", null ],
    [ "buttonStateFromMouseEvent", "group__new__in__4__11.html#ga9e7a18104859beae1f325157d78ea771", null ],
    [ "castKeyboardEvent", "group__new__in__4__11.html#ga5c1189f0ec81a4a69177a54f33807f89", null ],
    [ "castMouseCancelEvent", "group__new__in__4__11.html#ga735b6cbbe079cc47386e93e54e78858c", null ],
    [ "castMouseDownEvent", "group__new__in__4__11.html#ga9b981618b2668e771cde9efe0066d79b", null ],
    [ "castMouseEnterEvent", "group__new__in__4__11.html#gac70bfb1c6914453bce989e7cab7297c9", null ],
    [ "castMouseEvent", "group__new__in__4__11.html#ga59149aa8557903506298652bebb167ed", null ],
    [ "castMouseExitEvent", "group__new__in__4__11.html#gaacd4cd83be7b56593d42dcbbc80d1f4b", null ],
    [ "castMouseMoveEvent", "group__new__in__4__11.html#ga7238ee0c38d46bebdbbe74f43edde602", null ],
    [ "castMousePositionEvent", "group__new__in__4__11.html#ga25cb36f2091205fd59010c46581c031b", null ],
    [ "castMouseUpEvent", "group__new__in__4__11.html#gab487782b79460e5e1954bfdb50c6d038", null ],
    [ "castMouseWheelEvent", "group__new__in__4__11.html#gad1f2e10970572c81bd7156a97eafd2f8", null ],
    [ "castZoomGestureEvent", "group__new__in__4__11.html#gadae423c20ad541c299c37f14f60aec82", null ],
    [ "toVstVirtualKey", "group__new__in__4__11.html#ga010ad00fd4fa3deaa934b01b4a4e1ba1", null ],
    [ "viewOnMouseEnabled", "group__new__in__4__11.html#gae5d3445d69a1041130b8d453258f6a1e", null ]
];